@@ -33,17 +33,16 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import, annotations, print_function
+from __future__ import annotations
 
 import functools
 import operator
 import os
+import pickle  # noqa: S403
 import re
 import subprocess
 from typing import Dict, List
-
-from six.moves import cPickle as pickle
-from six.moves.urllib_parse import quote
+from urllib.parse import quote
 
 import univention.debug as ud
 import univention.lib.listenerSharePath
